@@ -37,7 +37,7 @@
 #include "udiskslinuxmdraid.h"
 #include "udiskslinuxblockobject.h"
 #include "udisksdaemon.h"
-#include "udiskscleanup.h"
+#include "udisksstate.h"
 #include "udisksdaemonutil.h"
 #include "udiskslinuxdevice.h"
 
@@ -311,18 +311,18 @@ udisks_linux_mdraid_update (UDisksLinuxMDRaid       *mdraid,
   if (member_devices != NULL)
     {
       device = UDISKS_LINUX_DEVICE (member_devices->data);
-      num_devices = g_udev_device_get_property_as_int (device->udev_device, "MD_MEMBER_DEVICES");
-      level = g_udev_device_get_property (device->udev_device, "MD_MEMBER_LEVEL");
-      uuid = g_udev_device_get_property (device->udev_device, "MD_MEMBER_UUID");
-      name = g_udev_device_get_property (device->udev_device, "MD_MEMBER_NAME");
+      num_devices = g_udev_device_get_property_as_int (device->udev_device, "UDISKS_MD_MEMBER_DEVICES");
+      level = g_udev_device_get_property (device->udev_device, "UDISKS_MD_MEMBER_LEVEL");
+      uuid = g_udev_device_get_property (device->udev_device, "UDISKS_MD_MEMBER_UUID");
+      name = g_udev_device_get_property (device->udev_device, "UDISKS_MD_MEMBER_NAME");
     }
   else
     {
       device = UDISKS_LINUX_DEVICE (raid_device);
-      num_devices = g_udev_device_get_property_as_int (device->udev_device, "MD_DEVICES");
-      level = g_udev_device_get_property (device->udev_device, "MD_LEVEL");
-      uuid = g_udev_device_get_property (device->udev_device, "MD_UUID");
-      name = g_udev_device_get_property (device->udev_device, "MD_NAME");
+      num_devices = g_udev_device_get_property_as_int (device->udev_device, "UDISKS_MD_DEVICES");
+      level = g_udev_device_get_property (device->udev_device, "UDISKS_MD_LEVEL");
+      uuid = g_udev_device_get_property (device->udev_device, "UDISKS_MD_UUID");
+      name = g_udev_device_get_property (device->udev_device, "UDISKS_MD_NAME");
     }
 
   /* figure out size */
@@ -476,6 +476,12 @@ udisks_linux_mdraid_update (UDisksLinuxMDRaid       *mdraid,
                   g_strstrip (member_state);
                   member_state_elements = g_strsplit (member_state, ",", 0);
                 }
+              else
+                {
+                  // g_variant_new() doesn't like NULL pointers for empty
+                  // arrays
+                  member_state_elements = g_new0 (gchar*, 1);
+                }
 
               snprintf (buf, sizeof (buf), "md/%s/slot", file_name);
               member_slot = read_sysfs_attr (raid_device->udev_device, buf);
@@ -572,7 +578,7 @@ handle_start (UDisksMDRaid           *_mdraid,
 {
   UDisksLinuxMDRaid *mdraid = UDISKS_LINUX_MDRAID (_mdraid);
   UDisksDaemon *daemon;
-  UDisksCleanup *cleanup;
+  UDisksState *state;
   UDisksLinuxMDRaidObject *object;
   const gchar *action_id;
   const gchar *message;
@@ -598,7 +604,7 @@ handle_start (UDisksMDRaid           *_mdraid,
     }
 
   daemon = udisks_linux_mdraid_object_get_daemon (object);
-  cleanup = udisks_daemon_get_cleanup (daemon);
+  state = udisks_daemon_get_state (daemon);
 
   g_variant_lookup (options, "start-degraded", "b", &opt_start_degraded);
 
@@ -689,8 +695,7 @@ handle_start (UDisksMDRaid           *_mdraid,
       g_dbus_method_invocation_return_error (invocation,
                                              UDISKS_ERROR,
                                              UDISKS_ERROR_FAILED,
-                                             "No block interface for object",
-                                             raid_device_file);
+                                             "No block interface for object");
       goto out;
     }
   raid_device_file = udisks_block_dup_device (block);
@@ -717,9 +722,9 @@ handle_start (UDisksMDRaid           *_mdraid,
   raid_device_num = statbuf.st_rdev;
 
   /* update the mdraid file */
-  udisks_cleanup_add_mdraid (cleanup,
-                             raid_device_num,
-                             caller_uid);
+  udisks_state_add_mdraid (state,
+                           raid_device_num,
+                           caller_uid);
 
   /* TODO: wait for array to actually show up in udisks? Probably */
 
@@ -746,7 +751,7 @@ handle_stop (UDisksMDRaid           *_mdraid,
 {
   UDisksLinuxMDRaid *mdraid = UDISKS_LINUX_MDRAID (_mdraid);
   UDisksDaemon *daemon;
-  UDisksCleanup *cleanup;
+  UDisksState *state;
   UDisksLinuxMDRaidObject *object;
   uid_t started_by_uid;
   uid_t caller_uid;
@@ -765,7 +770,7 @@ handle_stop (UDisksMDRaid           *_mdraid,
     }
 
   daemon = udisks_linux_mdraid_object_get_daemon (object);
-  cleanup = udisks_daemon_get_cleanup (daemon);
+  state = udisks_daemon_get_state (daemon);
 
   error = NULL;
   if (!udisks_daemon_util_get_caller_uid_sync (daemon,
@@ -789,9 +794,9 @@ handle_stop (UDisksMDRaid           *_mdraid,
       goto out;
     }
 
-  if (!udisks_cleanup_has_mdraid (cleanup,
-                                  g_udev_device_get_device_number (raid_device->udev_device),
-                                  &started_by_uid))
+  if (!udisks_state_has_mdraid (state,
+                                g_udev_device_get_device_number (raid_device->udev_device),
+                                &started_by_uid))
     {
       /* allow stopping arrays stuff not mentioned in mounted-fs, but treat it like root mounted it */
       started_by_uid = 0;
@@ -920,7 +925,7 @@ handle_remove_device (UDisksMDRaid           *_mdraid,
 {
   UDisksLinuxMDRaid *mdraid = UDISKS_LINUX_MDRAID (_mdraid);
   UDisksDaemon *daemon;
-  UDisksCleanup *cleanup;
+  UDisksState *state;
   UDisksLinuxMDRaidObject *object;
   const gchar *action_id;
   const gchar *message;
@@ -947,7 +952,7 @@ handle_remove_device (UDisksMDRaid           *_mdraid,
     }
 
   daemon = udisks_linux_mdraid_object_get_daemon (object);
-  cleanup = udisks_daemon_get_cleanup (daemon);
+  state = udisks_daemon_get_state (daemon);
 
   g_variant_lookup (options, "wipe", "b", &opt_wipe);
 
@@ -997,9 +1002,9 @@ handle_remove_device (UDisksMDRaid           *_mdraid,
       goto out;
     }
 
-  if (!udisks_cleanup_has_mdraid (cleanup,
-                                  g_udev_device_get_device_number (raid_device->udev_device),
-                                  &started_by_uid))
+  if (!udisks_state_has_mdraid (state,
+                                g_udev_device_get_device_number (raid_device->udev_device),
+                                &started_by_uid))
     {
       /* allow stopping arrays stuff not mentioned in mounted-fs, but treat it like root mounted it */
       started_by_uid = 0;
@@ -1127,7 +1132,7 @@ handle_add_device (UDisksMDRaid           *_mdraid,
 {
   UDisksLinuxMDRaid *mdraid = UDISKS_LINUX_MDRAID (_mdraid);
   UDisksDaemon *daemon;
-  UDisksCleanup *cleanup;
+  UDisksState *state;
   UDisksLinuxMDRaidObject *object;
   const gchar *action_id;
   const gchar *message;
@@ -1152,7 +1157,7 @@ handle_add_device (UDisksMDRaid           *_mdraid,
     }
 
   daemon = udisks_linux_mdraid_object_get_daemon (object);
-  cleanup = udisks_daemon_get_cleanup (daemon);
+  state = udisks_daemon_get_state (daemon);
 
   error = NULL;
   if (!udisks_daemon_util_get_caller_uid_sync (daemon,
@@ -1192,9 +1197,9 @@ handle_add_device (UDisksMDRaid           *_mdraid,
       goto out;
     }
 
-  if (!udisks_cleanup_has_mdraid (cleanup,
-                                  g_udev_device_get_device_number (raid_device->udev_device),
-                                  &started_by_uid))
+  if (!udisks_state_has_mdraid (state,
+                                g_udev_device_get_device_number (raid_device->udev_device),
+                                &started_by_uid))
     {
       /* allow stopping arrays stuff not mentioned in mounted-fs, but treat it like root mounted it */
       started_by_uid = 0;
@@ -1270,7 +1275,7 @@ handle_set_bitmap_location (UDisksMDRaid           *_mdraid,
 {
   UDisksLinuxMDRaid *mdraid = UDISKS_LINUX_MDRAID (_mdraid);
   UDisksDaemon *daemon;
-  UDisksCleanup *cleanup;
+  UDisksState *state;
   UDisksLinuxMDRaidObject *object;
   const gchar *action_id;
   const gchar *message;
@@ -1291,7 +1296,7 @@ handle_set_bitmap_location (UDisksMDRaid           *_mdraid,
     }
 
   daemon = udisks_linux_mdraid_object_get_daemon (object);
-  cleanup = udisks_daemon_get_cleanup (daemon);
+  state = udisks_daemon_get_state (daemon);
 
   error = NULL;
   if (!udisks_daemon_util_get_caller_uid_sync (daemon,
@@ -1322,9 +1327,9 @@ handle_set_bitmap_location (UDisksMDRaid           *_mdraid,
       goto out;
     }
 
-  if (!udisks_cleanup_has_mdraid (cleanup,
-                                  g_udev_device_get_device_number (raid_device->udev_device),
-                                  &started_by_uid))
+  if (!udisks_state_has_mdraid (state,
+                                g_udev_device_get_device_number (raid_device->udev_device),
+                                &started_by_uid))
     {
       /* allow stopping arrays stuff not mentioned in mounted-fs, but treat it like root mounted it */
       started_by_uid = 0;
@@ -1393,7 +1398,7 @@ handle_request_sync_action (UDisksMDRaid           *_mdraid,
 {
   UDisksLinuxMDRaid *mdraid = UDISKS_LINUX_MDRAID (_mdraid);
   UDisksDaemon *daemon;
-  UDisksCleanup *cleanup;
+  UDisksState *state;
   UDisksLinuxMDRaidObject *object;
   const gchar *action_id;
   const gchar *message;
@@ -1413,7 +1418,7 @@ handle_request_sync_action (UDisksMDRaid           *_mdraid,
     }
 
   daemon = udisks_linux_mdraid_object_get_daemon (object);
-  cleanup = udisks_daemon_get_cleanup (daemon);
+  state = udisks_daemon_get_state (daemon);
 
   error = NULL;
   if (!udisks_daemon_util_get_caller_uid_sync (daemon,
@@ -1446,9 +1451,9 @@ handle_request_sync_action (UDisksMDRaid           *_mdraid,
       goto out;
     }
 
-  if (!udisks_cleanup_has_mdraid (cleanup,
-                                  g_udev_device_get_device_number (raid_device->udev_device),
-                                  &started_by_uid))
+  if (!udisks_state_has_mdraid (state,
+                                g_udev_device_get_device_number (raid_device->udev_device),
+                                &started_by_uid))
     {
       /* allow stopping arrays stuff not mentioned in mounted-fs, but treat it like root mounted it */
       started_by_uid = 0;
